OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "無法寫入 \"config\" 目錄！",
    "This can usually be fixed by giving the web server write access to the config directory." : "允許網頁伺服器寫入 config 目錄通常可以解決這個問題。",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但如果您比較希望保留 config.php 的唯讀狀態，請在該設定檔中將 \"config_is_read_only\" 設定為 true。",
    "See %s" : "見 %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "應用程式 %1$s 不存在或有與此伺服器不相容的版本。請檢查應用程式目錄。",
    "Sample configuration detected" : "您目前正在使用範例設定",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接複製了範例設定來使用，這樣的安裝很可能會無法運作，請閱讀說明文件後對 config.php 進行適當的修改",
    "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
    "%s email verification" : "%s 電子郵件驗證",
    "Email verification" : "電子郵件驗證",
    "Click the following button to confirm your email." : "點擊以下按鈕以確認您的電子郵件。",
    "Click the following link to confirm your email." : "點擊以下連結以確認您的電子郵件。",
    "Confirm your email" : "確認您的電子郵件",
    "Other activities" : "其它活動",
    "%1$s and %2$s" : "%1$s 和 %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s 和 %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s、%2$s、%3$s 和 %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s、%2$s、%3$s、%4$s 和 %5$s",
    "Education Edition" : "教育版",
    "Enterprise bundle" : "企業組合包",
    "Groupware bundle" : "協作組合包",
    "Hub bundle" : "Hub 套裝",
    "Social sharing bundle" : "社交網絡組合包",
    "PHP %s or higher is required." : "需要 PHP %s 或更高版本",
    "PHP with a version lower than %s is required." : "需要 PHP 版本低於 %s ",
    "%sbit or higher PHP required." : "%s 或需要更高階版本的php",
    "The following architectures are supported: %s" : "支援下列架構：%s",
    "The following databases are supported: %s" : "支援下列資料庫：%s",
    "The command line tool %s could not be found" : "找不到命令列工具指令 %s",
    "The library %s is not available." : "套件庫 %s 無法使用",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "需要使用 %2$s 版以上的 %1$s 函式庫，目前可用的版本是 %3$s",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "需要使用 %2$s 版以下的 %1$s 函式庫，目前可用的版本是 %3$s",
    "The following platforms are supported: %s" : "支援下列平台：%s",
    "Server version %s or higher is required." : "需要伺服器版本 %s 或更高",
    "Server version %s or lower is required." : "需要伺服器版本 %s 或更低",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "登入帳號必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
    "Logged in account must be an admin or sub admin" : "登入的帳號必須要是管理員或是子管理員",
    "Logged in account must be an admin" : "登入的帳號必須有管理員權限",
    "Wiping of device %s has started" : "已開始抹除裝置 %s ",
    "Wiping of device »%s« has started" : "已開始抹除裝置「%s」",
    "»%s« started remote wipe" : "「%s」開始遠端抹除",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "裝置或應用程式「%s」已開始遠端抹除的程序，完成後您將會收到另一封通知信",
    "Wiping of device %s has finished" : "裝置 %s 抹除完成",
    "Wiping of device »%s« has finished" : "裝置「%s」抹除完成",
    "»%s« finished remote wipe" : "裝置「%s」完成遠端抹除",
    "Device or application »%s« has finished the remote wipe process." : "裝置或應用程式「%s」已完成遠端抹除",
    "Remote wipe started" : "遠端抹除已開始",
    "A remote wipe was started on device %s" : "遠端抹除已經在裝置 %s 開始",
    "Remote wipe finished" : "遠端抹除已完成",
    "The remote wipe on %s has finished" : "%s 的遠端抹除已經完成",
    "Authentication" : "認證",
    "Unknown filetype" : "未知的檔案類型",
    "Invalid image" : "無效的圖片",
    "Avatar image is not square" : "頭像不是正方形",
    "Files" : "檔案",
    "View profile" : "檢視個人檔案",
    "Local time: %s" : "本機時間：%s",
    "today" : "今天",
    "tomorrow" : "明天",
    "yesterday" : "昨天",
    "_in %n day_::_in %n days_" : ["在 %n 天內"],
    "_%n day ago_::_%n days ago_" : ["%n 天前"],
    "next month" : "下個月",
    "last month" : "上個月",
    "_in %n month_::_in %n months_" : ["在 %n 月內"],
    "_%n month ago_::_%n months ago_" : ["%n 個月前"],
    "next year" : "明年",
    "last year" : "去年",
    "_in %n year_::_in %n years_" : ["%n 年後"],
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_in %n hour_::_in %n hours_" : ["%n 小時後"],
    "_%n hour ago_::_%n hours ago_" : ["%n 小時前"],
    "_in %n minute_::_in %n minutes_" : ["%n 分鐘後"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分鐘前"],
    "in a few seconds" : "幾秒後",
    "seconds ago" : "幾秒前",
    "Empty file" : "空檔案",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "名為 %s 的模組不存在，請在應用程式設定中啟用，或是聯絡系統管理員",
    "File already exists" : "檔案已存在",
    "Invalid path" : "無效的路徑",
    "Failed to create file from template" : "無法從範本建立檔案",
    "Templates" : "範本",
    "File name is a reserved word" : "檔案名稱是保留字",
    "File name contains at least one invalid character" : "檔案名稱含有不允許的字元",
    "File name is too long" : "檔案名稱太長",
    "Dot files are not allowed" : "不允許小數點開頭的檔案",
    "Empty filename is not allowed" : "不允許空白的檔名",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "應用程式 \"%s\" 無法安裝，因為無法讀取 appinfo 檔案。",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "應用程式 \"%s\" 無法安裝，因為該應用程式不相容於目前版本的伺服器。",
    "__language_name__" : "正體中文（臺灣）",
    "This is an automatically sent email, please do not reply." : "此為自動寄送的電子郵件，請不要回覆。",
    "Help" : "說明",
    "Appearance and accessibility" : "外觀與無障礙存取",
    "Apps" : "應用程式",
    "Personal settings" : "個人設定",
    "Administration settings" : "管理設定",
    "Settings" : "設定",
    "Log out" : "登出",
    "Users" : "使用者",
    "Email" : "電子郵件",
    "Mail %s" : "傳送郵件給 %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "在 fediverse 上檢視 %s",
    "Phone" : "手機",
    "Call %s" : "與 %s 通話",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "在 Twitter 上檢視 %s",
    "Website" : "網站",
    "Visit %s" : "造訪 %s",
    "Address" : "地址",
    "Profile picture" : "個人檔案圖片",
    "About" : "關於",
    "Display name" : "顯示名稱",
    "Headline" : "標題",
    "Organisation" : "組織",
    "Role" : "角色",
    "Unknown account" : "未知的帳號",
    "Additional settings" : "其他設定",
    "Enter the database Login and name for %s" : "輸入 %s 的資料庫帳號與名稱",
    "Enter the database Login for %s" : "輸入 %s 的資料庫帳號",
    "Enter the database name for %s" : "輸入 %s 的資料庫名稱",
    "You cannot use dots in the database name %s" : "資料庫名稱 %s 不能包含小數點",
    "MySQL Login and/or password not valid" : "MySQL 帳號或密碼不正確",
    "You need to enter details of an existing account." : "您必須輸入現有帳號的資訊",
    "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
    "Oracle Login and/or password not valid" : "Oracle 帳號或密碼不正確",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL 帳號或密碼無效",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "不支援 Mac OS X 而且 %s 在這個平台上面無法正常運作，請自行衡量風險後使用！",
    "For the best results, please consider using a GNU/Linux server instead." : "請考慮使用 GNU/Linux 伺服器以獲得最佳體驗",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在 32 位元的 PHP 環境運行，並且 php.ini 中被設置了 open_basedir 參數，這將讓超過 4GB 的檔案操作發生問題，強烈建議您更改設定。",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP",
    "Set an admin Login." : "設定管理員帳號。",
    "Set an admin password." : "設定管理員密碼",
    "Cannot create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "分享後端 %s 必須實作 OCP\\Share_Backend 界面",
    "Sharing backend %s not found" : "找不到分享後端 %s",
    "Sharing backend for %s not found" : "找不到 %s 的分享後端",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 與您分享了 %2$s ，且想要加入：",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s 與您分享了 %2$s ，且想要加入",
    "»%s« added a note to a file shared with you" : "%s 在與您分享的檔案中加入了註解",
    "Open »%s«" : "開啟 »%s«",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "You are not allowed to share %s" : "你不被允許分享 %s",
    "Cannot increase permissions of %s" : "無法增加 %s 的權限",
    "Files cannot be shared with delete permissions" : "無法分享具有刪除權限的檔案",
    "Files cannot be shared with create permissions" : "無法分享具有新建權限的檔案",
    "Expiration date is in the past" : "到期日為過去的日期",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["無法設定到期日超過未來%n天"],
    "Sharing is only allowed with group members" : "僅允許與群組成員分享",
    "Sharing %s failed, because this item is already shared with the account %s" : "分享 %s 失敗，因為此項目已與帳號 %s 分享",
    "%1$s shared »%2$s« with you" : "%1$s 與您分享了 %2$s",
    "%1$s shared »%2$s« with you." : "%1$s 與您分享了 %2$s",
    "Click the button below to open it." : "點下方連結開啟",
    "The requested share does not exist anymore" : "該分享已經不存在",
    "The requested share comes from a disabled user" : "請求的分享來自已停用的使用者",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "未建立使用者，因為已達使用者上限。請檢查您的通知以取得更多資訊。",
    "Could not find category \"%s\"" : "找不到分類：\"%s\"",
    "Sunday" : "週日",
    "Monday" : "週一",
    "Tuesday" : "週二",
    "Wednesday" : "週三",
    "Thursday" : "週四",
    "Friday" : "週五",
    "Saturday" : "週六",
    "Sun." : "日",
    "Mon." : "一",
    "Tue." : "二",
    "Wed." : "三",
    "Thu." : "四",
    "Fri." : "五",
    "Sat." : "六",
    "Su" : "日",
    "Mo" : "一",
    "Tu" : "二",
    "We" : "三",
    "Th" : "四",
    "Fr" : "五",
    "Sa" : "六",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Jan." : "一月",
    "Feb." : "二月",
    "Mar." : "三月",
    "Apr." : "四月",
    "May." : "五月",
    "Jun." : "六月",
    "Jul." : "七月",
    "Aug." : "八月",
    "Sep." : "九月",
    "Oct." : "十月",
    "Nov." : "十一月",
    "Dec." : "十二月",
    "A valid password must be provided" : "須提供有效的密碼",
    "The Login is already being used" : "這個帳號已經有人使用了",
    "Could not create account" : "無法建立帳號",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "帳號僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
    "A valid Login must be provided" : "必須提供有效帳號",
    "Login contains whitespace at the beginning or at the end" : "帳號的開頭或結尾有空白",
    "Login must not consist of dots only" : "帳號不能只包含小數點",
    "Login is invalid because files already exist for this user" : "帳號無效，因為使用者的檔案已經存在",
    "Account disabled" : "帳號已停用",
    "Login canceled by app" : "應用程式取消了登入",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "應用程式 \"%1$s\" 無法被安裝，缺少下列所需元件： %2$s",
    "a safe home for all your data" : "您資料的安全屋",
    "File is currently busy, please try again later" : "檔案目前忙碌中，請稍候再試",
    "Cannot download file" : "無法下載檔案",
    "Application is not enabled" : "應用程式未啟用",
    "Authentication error" : "認證錯誤",
    "Token expired. Please reload page." : "Token 過期，請重新整理頁面。",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "沒有安裝資料庫驅動程式 (sqlite, mysql, 或 postgresql)",
    "Cannot write into \"config\" directory." : "無法寫入「config」目錄。",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "允許網頁伺服器寫入 config 目錄通常可以解決這個問題，詳見 %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "或者，如果您比較希望保留 config.php 的唯讀狀態，請在該設定檔中將 \"config_is_read_only\" 設定為 true。見%s",
    "Cannot write into \"apps\" directory." : "無法寫入「apps」目錄",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "允許網頁伺服器寫入 apps 目錄或是在設定檔中停用應用程式商店通常可以解決這個問題。",
    "Cannot create \"data\" directory." : "無法建立「data」目錄。",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "開放網頁伺服器存取根目錄通常就可以修正這個問題，詳見 %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "開放網頁伺服器存取根目錄通常就可以修正權限問題，詳見 %s。",
    "Your data directory is not writable." : "您的 data 目錄無法寫入。",
    "Setting locale to %s failed." : "將地區設定為 %s 時失敗。",
    "Please install one of these locales on your system and restart your web server." : "請在您的系統上安裝這些地區設定中的其中一個，然後重新啟動網頁伺服器。",
    "PHP module %s not installed." : "未安裝 PHP 模組 %s",
    "Please ask your server administrator to install the module." : "請詢問系統管理員來安裝這些模組",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP 設定值 \"%s\" 沒有被設定為 \"%s\"",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "調整 php.ini 中的設定，使 Nextcloud 重新運作",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> 被設定為 <code>%s</code> 而非預期中的 <code>0</code>。",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>。",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 已經設定成「剪除 inline doc block」模式，這將會使幾個核心應用程式無法使用",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "這大概是由快取或是加速器像是 Zend OPcache, eAccelerator 造成的",
    "PHP modules have been installed, but they are still listed as missing?" : "你已經安裝了指定的 PHP 模組，可是還是顯示為找不到嗎？",
    "Please ask your server administrator to restart the web server." : "請聯絡您的系統管理員重新啟動網頁伺服器",
    "The required %s config variable is not configured in the config.php file." : "必要的 %s 設定變數未在 config.php 檔案中設定。",
    "Please ask your server administrator to check the Nextcloud configuration." : "請聯絡您的伺服器管理員檢查 Nextcloud 設定。",
    "Your data directory is readable by other people." : "您的 data 目錄可被其他使用者讀取。",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表",
    "Your data directory must be an absolute path." : "您的 data 目錄必須是絕對路徑。",
    "Check the value of \"datadirectory\" in your configuration." : "請檢查您設定檔中「datadirectory」的值。",
    "Your data directory is invalid." : "您的 data 目錄無效。",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "請確保資料目錄最上層有一個 \".ocdata\" 檔案",
    "Action \"%s\" not supported or implemented." : "操作 \"%s\" 並未支援，或是尚未實作",
    "Authentication failed, wrong token or provider ID given" : "認證失敗，提供了錯誤的 token 或是 provider ID",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "欠缺完成請求所需的參數： \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" 已經被另一個雲端聯盟供應者 \"%2$s\" 所使用",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID 為「%s」的雲端聯盟提供者不存在。",
    "Could not obtain lock type %d on \"%s\"." : "無法取得鎖定：類型 %d ，檔案 %s",
    "Storage unauthorized. %s" : "儲存空間未經授權。%s",
    "Storage incomplete configuration. %s" : "儲存空間配置尚未完成。%s",
    "Storage connection error. %s" : "儲存空間連線錯誤。%s",
    "Storage is temporarily not available" : "儲存空間暫時無法使用",
    "Storage connection timeout. %s" : "儲存空間連線逾時。%s",
    "Free prompt" : "免費提示詞",
    "Runs an arbitrary prompt through the language model." : "透過語言模型執行任意提示詞。",
    "Generate headline" : "產生標題",
    "Generates a possible headline for a text." : "為文字產生可能的標題。",
    "Summarize" : "總結",
    "Summarizes text by reducing its length without losing key information." : "透過減少文字長度來總結而不遺失關鍵資訊。",
    "Extract topics" : "擷取主題",
    "Extracts topics from a text and outputs them separated by commas." : "從文字中擷取主題並輸出，然後用逗號分隔。",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "應用程式 %1$s 中的檔案沒有被正確取代，請確認它的版本與伺服器相容。",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登入使用者必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
    "Logged in user must be an admin or sub admin" : "登入的使用者必須要是管理員或是子管理員",
    "Logged in user must be an admin" : "登入的使用者必須有管理員權限",
    "Full name" : "全名",
    "Unknown user" : "未知的使用者",
    "Enter the database username and name for %s" : "輸入 %s 的資料庫名稱及使用者名稱",
    "Enter the database username for %s" : "輸入 %s 的資料庫使用者暱稱",
    "MySQL username and/or password not valid" : "MySQL 使用者名稱或密碼不正確",
    "Oracle username and/or password not valid" : "Oracle 用戶名和/或密碼無效",
    "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
    "Set an admin username." : "設定管理員帳號",
    "Sharing %s failed, because this item is already shared with user %s" : "分享 %s 失敗，因為此項目已與使用者 %s 分享",
    "The username is already being used" : "這個使用者名稱已經有人使用了",
    "Could not create user" : "無法建立使用者",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "使用者名稱僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
    "A valid username must be provided" : "必須提供一個有效的用戶名",
    "Username contains whitespace at the beginning or at the end" : "用戶名的開頭或結尾有空白",
    "Username must not consist of dots only" : "使用者名稱不能只包含小數點",
    "Username is invalid because files already exist for this user" : "使用者名稱無效，因為使用者的檔案已經存在",
    "User disabled" : "使用者已停用",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 版本最低需求為 2.7.0。目前安裝版本為 %s 。",
    "To fix this issue update your libxml2 version and restart your web server." : "修正方式為更新您的 libxml2 為 2.7.0 以上版本，再重啟網頁伺服器。",
    "PostgreSQL >= 9 required." : "需要 PostgreSQL 版本 >= 9。",
    "Please upgrade your database version." : "請升級您的資料庫版本。",
    "Your data directory is readable by other users." : "您的 data 目錄可被其他使用讀取。",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表"
},
"nplurals=1; plural=0;");
